==> libreoffice_4.2.3~rc3.orig.tar.xz: libreoffice-4.2.3~rc3/qadevOOo/tests/java/ifc/container/_XEnumerationAccess.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package ifc.container;

import lib.MultiMethodTest;

import com.sun.star.container.XEnumeration;
import com.sun.star.container.XEnumerationAccess;


/**
* Testing <code>com.sun.star.container.XEnumerationAccess</code>
* interface methods. <p>
* Test is multithread compilant. <p>
*/
public class _XEnumerationAccess extends MultiMethodTest{
    public XEnumerationAccess oObj = null;

    /**
    * Test calls the method and checks return value. <p>
    * Has <b> OK </b> status if the method returns not null value. <p>
    */
    public void _createEnumeration(){
        log.println( "createing Enumeration" );
        XEnumeration oEnum = oObj.createEnumeration();
        tRes.tested( "createEnumeration()", oEnum != null );
        return;
    } // end createEnumeration()
}  // finish class _XEnumerationAccess

==> libreoffice_5.1.6~rc2.orig.tar.xz: libreoffice-5.1.6~rc2/qadevOOo/tests/java/ifc/container/_XEnumerationAccess.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package ifc.container;

import lib.MultiMethodTest;

import com.sun.star.container.XEnumeration;
import com.sun.star.container.XEnumerationAccess;


/**
* Testing <code>com.sun.star.container.XEnumerationAccess</code>
* interface methods. <p>
* Test is multithread compliant. <p>
*/
public class _XEnumerationAccess extends MultiMethodTest{
    public XEnumerationAccess oObj = null;

    /**
    * Test calls the method and checks return value. <p>
    * Has <b> OK </b> status if the method returns not null value. <p>
    */
    public void _createEnumeration(){
        log.println( "createing Enumeration" );
        XEnumeration oEnum = oObj.createEnumeration();
        tRes.tested( "createEnumeration()", oEnum != null );
    } // end createEnumeration()
}  // finish class _XEnumerationAccess
